# eric7.Plugins.VcsPlugins.vcsMercurial.LargefilesExtension.LfConvertDataDialog

Module implementing a dialog to enter the data for the repo conversion.

### Global Attributes

None

### Classes

LfConvertDataDialog | Class implementing a dialog to enter the data for the repo conversion.

### Functions

None

## LfConvertDataDialog

Class implementing a dialog to enter the data for the repo conversion.

### Derived from

QDialog, Ui_LfConvertDataDialog

### Class Attributes

None

### Class Methods

None

### Methods

LfConvertDataDialog | Constructor
getData | Public method to retrieve the entered data.
on_newProjectPicker_textChanged | Private slot to handle editing of the new project directory.

### Static Methods

None

#### LfConvertDataDialog (Constructor)

LfConvertDataDialog(currentPath, mode, parent=None)

Constructor

currentPath (str)
  directory name of the current project
mode (str)
  dialog mode (one of 'largefiles' or 'normal')
parent (QWidget)
  reference to the parent widget

#### LfConvertDataDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple containing the new project directory name, minimum file size and file patterns

Return Type:
  tuple of (str, int, list of str)

#### LfConvertDataDialog.on_newProjectPicker_textChanged

on_newProjectPicker_textChanged(txt)

Private slot to handle editing of the new project directory.

txt (str)
  new project directory name

Up